Loupe
=====
|build status| |coverage| |docs status| |pypi version|

Loupe is a Python library for solving parametric optimization problems. Loupe makes 
it easy to build and manipulate numerical models and efficiently solve optimization 
problems using built-in algorithmic differentiation (autograd).

* **Documentation:** https://loupe.readthedocs.io/
* **Releases:** https://pypi.org/project/loupe/
* **Code:** https://github.com/andykee/loupe/
* **Issue tracker:** https://github.com/andykee/loupe/issues/

Installing
----------
Install and update Loupe using `pip`_:

.. code-block:: text

    pip install loupe


.. _pip: https://pip.pypa.io/en/stable/quickstart/

.. |build status| image:: https://github.com/andykee/loupe/actions/workflows/test.yml/badge.svg
    :target: https://github.com/andykee/loupe/actions/workflows/test.yml

.. |coverage| image:: https://coveralls.io/repos/github/andykee/loupe/badge.svg
    :target: https://coveralls.io/github/andykee/loupe

.. |docs status| image:: https://readthedocs.org/projects/loupe/badge/?version=latest
    :target: https://loupe.readthedocs.io/en/latest/?badge=latest
    
.. |pypi version| image:: https://img.shields.io/pypi/v/loupe.svg
    :target: https://pypi.python.org/pypi/loupe
